@@ -18,7 +18,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package WebFetch;
-$WebFetch::VERSION = '0.15.4';
+$WebFetch::VERSION = '0.15.5';
 
 use Carp qw(croak);
 use Getopt::Long;
@@ -43,15 +43,15 @@ Readonly::Array my @WebFetch_formatters => qw( output:html output:xml output:wf
 # defualy modules for input and output
 Readonly::Hash my %default_modules => (
     "input" => {
-        "rss"        => "WebFetch::Input::RSS",
+        "rss"        => "WebFetch::RSS",
         "sitenews"   => "WebFetch::Input::SiteNews",
         "perlstruct" => "WebFetch::Input::PerlStruct",
         "atom"       => "WebFetch::Input::Atom",
         "dump"       => "WebFetch::Input::Dump",
     },
     "output" => {
-        "rss"        => "WebFetch::Output:RSS",
-        "atom"       => "WebFetch::Output:Atom",
+        "rss"        => "WebFetch::RSS",
+        "atom"       => "WebFetch::Atom",
         "tt"         => "WebFetch::Output:TT",
         "perlstruct" => "WebFetch::Output::PerlStruct",
         "dump"       => "WebFetch::Output::Dump",
@@ -1837,7 +1837,7 @@ WebFetch - Perl module to download/fetch and save information from the Web
 
 =head1 VERSION
 
-version 0.15.4
+version 0.15.5
 
 =head1 SYNOPSIS
 
@@ -2730,7 +2730,7 @@ L<WebFetch::Data::Store>
 
 Modules separated to contain external module dependencies:
 L<WebFetch::Input::Atom>,
-L<WebFetch::Input::RSS>,
+L<WebFetch::RSS>,
 L<WebFetch::Output::TT>,
 L<WebFetch::Output::TWiki>,
 
